##  Next Steps
After you process all items, add information about the ownership and business context of the applications. You can then review technical risks in your landscape and plan your next transformations.
**Tip**
To maintain a clear overview of discovered items, address them promptly. This approach makes it easier to identify and manage newly deployed SAP services. It also helps eliminate uncertainties in your enterprise architecture landscape.
